aboutsummaryrefslogtreecommitdiff
path: root/gcc/tree.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/tree.h')
-rw-r--r--gcc/tree.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/tree.h b/gcc/tree.h
index d40d416..6cae818 100644
--- a/gcc/tree.h
+++ b/gcc/tree.h
@@ -2654,16 +2654,16 @@ extern vec<tree, va_gc> **decl_debug_args_insert (tree);
#define TREE_OPTIMIZATION_BASE_OPTABS(NODE) \
(OPTIMIZATION_NODE_CHECK (NODE)->optimization.base_optabs)
-/* Return a tree node that encapsulates the current optimization options. */
-extern tree build_optimization_node (void);
+/* Return a tree node that encapsulates the optimization options in OPTS. */
+extern tree build_optimization_node (struct gcc_options *opts);
extern void init_tree_optimization_optabs (tree);
#define TREE_TARGET_OPTION(NODE) \
(&TARGET_OPTION_NODE_CHECK (NODE)->target_option.opts)
-/* Return a tree node that encapsulates the current target options. */
-extern tree build_target_option_node (void);
+/* Return a tree node that encapsulates the target options in OPTS. */
+extern tree build_target_option_node (struct gcc_options *opts);
#if defined ENABLE_TREE_CHECKING && (GCC_VERSION >= 2007)